Stan Math Library: Namespace Members

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Namespace List
- Namespace Members

- All
- Functions
- Variables
- Typedefs

- c
- e
- i
- l
- m
- n
- p
- s
- t

### - c -

- CONSTRAINT_TOLERANCE : stan::math

### - e -

- E : stan::math
- EPSILON : stan::math

### - i -

- INFTY : stan::math
- INV_SQRT_2 : stan::math
- INV_SQRT_TWO_PI : stan::math

### - l -

- LOG_10 : stan::math
- LOG_2 : stan::math
- LOG_HALF : stan::math
- LOG_PI : stan::math
- LOG_PI_OVER_FOUR : stan::math
- LOG_SQRT_PI : stan::math
- LOG_TWO : stan::math
- LOG_TWO_PI : stan::math
- LOG_ZERO : stan::math

### - m -

- MAJOR_VERSION : stan::math
- MINOR_VERSION : stan::math

### - n -

- NEG_LOG_PI : stan::math
- NEG_LOG_SQRT_PI : stan::math
- NEG_LOG_SQRT_TWO_PI : stan::math
- NEG_LOG_TWO : stan::math
- NEG_LOG_TWO_OVER_TWO : stan::math
- NEG_LOG_TWO_PI : stan::math
- NEG_TWO_OVER_SQRT_PI : stan::math
- NEGATIVE_EPSILON : stan::math
- NEGATIVE_INFTY : stan::math
- NOT_A_NUMBER : stan::math

### - p -

- PATCH_VERSION : stan::math
- POISSON_MAX_RATE : stan::math

### - s -

- SQRT_2 : stan::math
- SQRT_2_TIMES_SQRT_PI : stan::math
- SQRT_PI : stan::math

### - t -

- TWO_OVER_SQRT_PI : stan::math

[ Stan Home Page ] © 2011–2016, Stan Development Team.